#
# spec file for package nuspell
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define sonum   3
%define libname libnuspell
Name:           nuspell
Version:        3.1.0.1586261062.d811a91
Release:        0
Summary:        A spell checker library and command-line tool
License:        LGPL-3.0-or-later
Group:          Productivity/Office/Other
URL:            https://nuspell.github.io/
Source:         %{name}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libboost_locale-devel
BuildRequires:  libicu-devel
Requires:       hunspell
BuildRequires:  rubygem(%{rb_default_ruby_abi}:ronn)

%description
Nuspell is a free and open source spell checker that is written in modern C++.
It is designed for languages with rich morphology and complex word compounding.

Main features are:
 - Full unicode support backed by ICU
 - Backward compatibility with Hunspell dictionary file format
 - Twofold affix stripping (for agglutinative languages, like Azeri,
   Basque, Estonian, Finnish, Hungarian, Turkish, etc.)
 - Support complex compounds (for example, Hungarian, Germand and Dutch)
 - Support language specific features (for example, special casing of
   Azeri and Turkish dotted i, or German sharp s)
 - Handle conditional affixes, circumfixes, fogemorphemes, forbidden
   words, pseudoroots and homonyms.

%package -n %{libname}%{sonum}
Summary:        A spell checker library and command-line tool

%description -n %{libname}%{sonum}
Nuspell is a free and open source spell checker that is written in modern C++.
It is designed for languages with rich morphology and complex word compounding.

Main features are:
 - Full unicode support backed by ICU
 - Backward compatibility with Hunspell dictionary file format
 - Twofold affix stripping (for agglutinative languages, like Azeri,
   Basque, Estonian, Finnish, Hungarian, Turkish, etc.)
 - Support complex compounds (for example, Hungarian, Germand and Dutch)
 - Support language specific features (for example, special casing of
   Azeri and Turkish dotted i, or German sharp s)
 - Handle conditional affixes, circumfixes, fogemorphemes, forbidden
   words, pseudoroots and homonyms.

%package devel
Summary:        Files for developing with Nuspell
Requires:       nuspell = %{version}-%{release}
Requires:       pkgconfig

%description devel
Includes and definitions for developing with Nuspell

%prep
%autosetup

%build
%cmake -DBUILD_SHARED_LIBS=ON \
 -DBUILD_TESTING=OFF \
 ..

%cmake_build

%install
%cmake_install

%post -n %{libname}%{sonum} -p /sbin/ldconfig
%postun -n %{libname}%{sonum} -p /sbin/ldconfig

%files -n %{name}
%{_bindir}/nuspell
%{_mandir}/man1/nuspell.1%{?ext_man}

%files -n %{libname}%{sonum}
%doc README.md CHANGELOG.md AUTHORS
%license COPYING.LESSER COPYING
%{_libdir}/%{libname}.so.*
%exclude %{_datadir}/doc/nuspell/README.md

%files devel

%{_includedir}/%{name}
%{_libdir}/%{libname}.so
%{_libdir}/pkgconfig/nuspell.pc
%{_libdir}/cmake/%{name}

%changelog
